django-simple-permissions
==========================
.. image:: https://secure.travis-ci.org/lambdalisue/django-permission.png?branch=master
    :target: http://travis-ci.org/lambdalisue/django-permission
    :alt: Build status

.. image:: https://coveralls.io/repos/lambdalisue/django-permission/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/lambdalisue/django-permission?branch=master 
    :alt: Coverage

.. image:: https://requires.io/github/lambdalisue/django-permission/requirements.svg?branch=master
    :target: https://requires.io/github/lambdalisue/django-permission/requirements/?branch=master
    :alt: Requirements Status

.. image:: https://scrutinizer-ci.com/g/lambdalisue/django-permission/badges/quality-score.png?b=master
    :target: https://scrutinizer-ci.com/g/lambdalisue/django-permission/inspections
    :alt: Inspection

.. image:: https://img.shields.io/badge/version-0.9.2-yellow.svg?style=flat-square
    :target: setup.py
    :alt: Version 0.9.2

.. image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square
    :target: LICENSE.md
    :alt: MIT License

Author
    Giovabal <giovabal@gmail.com>
Supported python versions
    Python 2.6, 2.7, 3.3, 3.4, 3.5
Supported django versions
    Django 1.2 - 1.9

A fork and semplification of [django-permission](https://github.com/lambdalisue/django-permission/), by Alisue 
